from bundlewrap.exceptions import BundleError

repo.libs.tools.require_bundle(node, 'systemd')

files = {
    '/etc/network/interfaces': {
        'delete': True,
    },
    '/etc/resolv.conf': {
        'content_type': 'mako',
    },
}

directories = {
    '/etc/systemd/network': {
        'purge': True,
        'needed_by': {
            'svc_systemd:systemd-networkd',
        },
        'triggers': {
            'svc_systemd:systemd-networkd:restart',
        },
    },
}

mac_host_prefix = '%04x' % (node.magic_number % 65534)
generated_mac = f'52:54:00:{mac_host_prefix[0:2]}:{mac_host_prefix[2:4]}:{{}}'

for interface, config in node.metadata.get('interfaces').items():
    if config.get('dhcp', False):
        if 'vlans' in config:
            raise BundleError(f'{node.name} interface {interface} cannot use vlans and dhcp!')
        template = 'template-iface-dhcp.network'
    else:
        template = 'template-iface-nodhcp.network'

    if '.' in interface:
        vlan_id = int(interface.split('.')[1])
        vlan_hex = '%02x' % (vlan_id % 255)
        files[f'/etc/systemd/network/{interface}.netdev'] = {
            'source': 'template-iface-vlan.netdev',
            'content_type': 'mako',
            'context': {
                'interface': interface,
                'vlan': vlan_id,
                'mac': generated_mac.format(vlan_hex)
            },
            'needed_by': {
                'svc_systemd:systemd-networkd',
            },
            'triggers': {
                'svc_systemd:systemd-networkd:restart',
            },
        }

    files[f'/etc/systemd/network/{interface}.network'] = {
        'source': template,
        'content_type': 'mako',
        'context': {
            'interface': interface,
            'config': config,
        },
        'needed_by': {
            'svc_systemd:systemd-networkd',
        },
        'triggers': {
            'svc_systemd:systemd-networkd:restart',
        },
    }

svc_systemd = {
    'systemd-networkd': {},
}
